package cn.rankin.tradeservice.controller;

import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.data.api.trade.dto.OrderDetailSearchDTO;
import cn.rankin.data.api.trade.dto.OrderSearchDTO;
import cn.rankin.data.api.trade.dto.OrderDTO;
import cn.rankin.data.api.trade.dto.OrderSnapshotSearchDTO;
import cn.rankin.data.api.trade.entity.Order;
import cn.rankin.data.api.trade.entity.OrderDetail;
import cn.rankin.data.api.trade.entity.OrderProductSnapshot;
import cn.rankin.tradeservice.service.OrderDetailService;
import cn.rankin.tradeservice.service.OrderProductSnapshotService;
import cn.rankin.tradeservice.service.OrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;

@RestController
@RequestMapping(value = "/order")
public class OrderController {

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        binder.registerCustomEditor(Date.class,
                new CustomDateEditor(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"), true));
    }

    @Autowired
    private OrderService orderService;

    @Autowired
    private OrderProductSnapshotService orderProductSnapshotService;

    @Autowired
    private OrderDetailService orderDetailService;

    // cms web需要做前置校验
    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Order> create(@RequestBody OrderDTO orderDTO) {
        return orderService.create(orderDTO);
    }

    @RequestMapping(value = "/{orderId}", method = RequestMethod.GET)
    public APIResult<Order> getOrder(@PathVariable String orderId) {
        return orderService.getOrder(orderId);
    }

    @RequestMapping(value = "/list", method = RequestMethod.POST)
    public APIResult<Page<Order>> search(@RequestBody OrderSearchDTO searchDTO) {
        return orderService.search(searchDTO);
    }

    @RequestMapping(value = "/pay/{orderId}", method = RequestMethod.POST)
    public APIResult<Boolean> pay(@PathVariable("orderId") String orderId) {
        return orderService.pay(orderId);
    }

    @RequestMapping(value = "/{orderId}", method = RequestMethod.DELETE)
    public APIResult<Boolean> cancel(@PathVariable("orderId") String orderId) {
        return orderService.cancel(orderId);
    }

    // 查询分拆订单
    @RequestMapping(value = "/detail", method = RequestMethod.POST)
    public APIResult<Page<OrderDetail>> search(@RequestBody OrderDetailSearchDTO searchDTO) {
        return orderDetailService.search(searchDTO);
    }

    // 查询交易快照
    @RequestMapping(value = "/snapshot", method = RequestMethod.POST)
    public APIResult<Page<OrderProductSnapshot>> search(@RequestBody OrderSnapshotSearchDTO searchDTO) {
        return orderProductSnapshotService.search(searchDTO);
    }

    @RequestMapping(value = "/send/{detailId}", method = RequestMethod.POST)
    public APIResult<Boolean> send(@PathVariable("detailId") String detailId) {
        return orderDetailService.send(detailId);
    }

    @RequestMapping(value = "/receive/{detailId}", method = RequestMethod.POST)
    public APIResult<Boolean> receive(@PathVariable("detailId") String detailId) {
        return orderDetailService.receive(detailId);
    }

}
